@@ -1,7 +1,7 @@
 #XXX MooseX::Declare
 package VAST::statement;
 BEGIN {
-  $VAST::statement::VERSION = '0.02';
+  $VAST::statement::VERSION = '0.03';
 }
 use utf8;
 use strict;
@@ -17,7 +17,12 @@ sub emit_m0ld {
     } elsif ($m->{statement_control}) {
         $m->{statement_control}->emit_m0ld;
     } elsif ($m->{EXPR} && $m->{EXPR}{circumfix} && $m->{EXPR}{circumfix}->isa('VAST::circumfix__S_Cur_Ly')) {
-        call 'postcircumfix:( )' => $m->{EXPR}->emit_m0ld,[capturize];
+        my $text = $m->{EXPR}{circumfix}{pblock}{blockoid}{TEXT};
+        if (defined $text && $text eq '{YOU_ARE_HERE}') {
+            Mildew::AST::Assign->new(lvalue=>reg '$YOU_ARE_HERE',rvalue=>call clone=>reg '$scope');
+        } else {
+            call 'postcircumfix:( )' => $m->{EXPR}->emit_m0ld,[capturize];
+        }
     } elsif ($m->{EXPR}) {
         $m->{EXPR}->emit_m0ld;
     } else {
